@@ -136,9 +136,9 @@ class SharingCriteria (Model):
         return self.name
 
 
-class Entrepreneur(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="entrepreneur_profile", on_delete=models.DO_NOTHING)
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="entrepreneurs")
+class Searcher(Model):
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="searcher_profile", on_delete=models.DO_NOTHING)
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="searchers")
     
     class Meta:
         auto_author = 'user'
@@ -148,24 +148,24 @@ class Entrepreneur(Model):
         authenticated_perms = ['inherit', 'add']
         serializer_fields=["@id", "user", "organisation"]
         nested_fields=["user", "organisation"]
-        container_path = 'entrepreneurs/'
-        rdf_type = 'coopstarter:entrepreneur'
+        container_path = 'searchers/'
+        rdf_type = 'coopstarter:searcher'
     
     def __str__(self):
         return self.user.get_full_name()
 
-class Mentor(Model):
-    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="mentor_profile", on_delete=models.DO_NOTHING)
+class Contributor(Model):
+    user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="contributor_profile", on_delete=models.DO_NOTHING)
     phone = models.CharField(max_length=25, null=True, blank=True, verbose_name='Phone number')
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="mentors")
-    country = models.ForeignKey(Country, null=True, related_name="mentors", on_delete=models.DO_NOTHING)
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="contributors")
+    country = models.ForeignKey(Country, null=True, related_name="contributors", on_delete=models.DO_NOTHING)
     languages = models.ManyToManyField(Language, blank=True)
 
     headline = models.CharField(max_length=256, blank=True, null=True, verbose_name='Headline or current position')
     city = models.CharField(max_length=256, blank=True, null=True, verbose_name='City')
 
     biography = models.TextField(blank=True, null=True, verbose_name="Tell us more about your activities")
-    skills = models.TextField(blank=True, null=True, verbose_name="What skills can you share with our entrepreneurs ?")
+    skills = models.TextField(blank=True, null=True, verbose_name="What skills can you share with our searchers ?")
 
     fields = models.ManyToManyField(Field, blank=True)
     organisationName = models.CharField(max_length=256, blank=True, null=True, verbose_name='Organisation name, to get info on unexisting ones')
@@ -181,8 +181,8 @@ class Mentor(Model):
         serializer_fields=["@id", "phone", "headline", "biography", "city", "skills", "linkedin",\
                            "twitter", "organisation", "fields", "languages", "country", "organisationContact", "organisationName"]
         nested_fields=["user", "organisation", "fields", "languages", "country"]
-        container_path = 'mentors/'
-        rdf_type = 'coopstarter:mentor'
+        container_path = 'contributors/'
+        rdf_type = 'coopstarter:contributor'
         owner_field = 'user'
         owner_perms = ['inherit', 'change', 'control', 'delete']
         anonymous_perms = ['view']
@@ -444,8 +444,8 @@ def sendMailToResourceSubmitter(sender, instance, created, **kwargs):
             html_message=message_html
         )
 
-@receiver(post_save, sender=Mentor)
-def create_mentor_profile(sender, instance, created, **kwargs):
+@receiver(post_save, sender=Contributor)
+def create_contributor_profile(sender, instance, created, **kwargs):
     if kwargs.get('raw', False):
         return False
 
@@ -453,18 +453,18 @@ def create_mentor_profile(sender, instance, created, **kwargs):
         staff = get_user_model().objects.filter(is_staff=True)
         for user in staff :
             message_text = loader.render_to_string(
-                'emails/txt/new_mentor_subscription.txt',
+                'emails/txt/new_contributor_subscription.txt',
                 {
                     'user': user,
-                    'mentor': instance,
+                    'contributor': instance,
                 }
             )
 
             message_html = loader.render_to_string(
-                'emails/html/new_mentor_subscription.html',
+                'emails/html/new_contributor_subscription.html',
                 {
                     'user': user,
-                    'mentor': instance,
+                    'contributor': instance,
                 }
             )
             send_mail(
